<?php 
// Performance Data Tool COMPONENT
//
//include the helper file
require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// respect the name
$performancedatatool_component_name="performancedatatool";

// run the initialization function
performancedatatool_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function performancedatatool_component_init(){
	global $performancedatatool_component_name;
	
	//boolean to check for latest version
	$versionok=performancedatatool_component_checkversion();
	
	//component description
	$desc="The purpose of the Performance Data Tool is to give you the ability to view and manipulate the .rrd and .xml performance data files on your Nagios XI host.";
	
	if(!$versionok)
		$desc="<b>Error: This component requires Nagios XI 2009R1.2B or later.</b>";
	
	//all components require a few arguments to be initialized correctly.  
	$args=array(
		COMPONENT_NAME => $performancedatatool_component_name,
		COMPONENT_VERSION => '2016-05-05', 
		COMPONENT_DATE => '2016-05-05',
		COMPONENT_AUTHOR => "Troy Lea aka Box293",
		COMPONENT_DESCRIPTION => $desc,
		COMPONENT_TITLE => "Performance Data Tool",
		// configuration function (optional)
		COMPONENT_CONFIGFUNCTION => "performancedatatool_component_config_func",
		);
	
	//register this component with XI 
	register_component($performancedatatool_component_name,$args);
	
	// register the addmenu function
	if($versionok)
		register_callback(CALLBACK_MENUS_INITIALIZED,'performancedatatool_component_addmenu');
	
	} /* End function performancedatatool_component_init(){ */
	


////////////////////////////////////////////////////////////////////////
// CONFIG FUNCTIONS
////////////////////////////////////////////////////////////////////////

function performancedatatool_component_config_func($mode="",$inargs,&$outargs,&$result) {
	// initialize return code and output
	$result = 0;
	$output = '
		<link href="../includes/components/performancedatatool/performance_data_tool.css" rel="stylesheet" type="text/css" />
		';

	$component_name = 'performancedatatool';

	switch($mode) {
		case COMPONENT_CONFIGMODE_GETSETTINGSHTML:
			/* Get the settings for the component */
			$settings_raw = get_option('performancedatatool_component_options');
			if($settings_raw == '') {
				/* There are currently no settings so define an array */
				$settings = array();
				} /* End if($settings_raw == '') { */
			else {
				/* Settings are defined so unserialize them */
				$settings = unserialize($settings_raw);
				} /* End else { */
			
			$html_folders_list = '';
			
			/* Get the initial values */
			$folders_list = grab_array_var($settings,'folders_list','');
			
			/* Get the values passed to us (usually after clicking apply) */
			$folders_list = grab_array_var($inargs,'folders_list',$folders_list);
			
			$component_url=get_component_url_base($component_name);
	
			$folder_list_counter = 0;
			
			/* Check to see if any custom folders have been defined */
			if (empty($folders_list)) {
				/* No custom folders */
				$html_folders_list .= 'You currently have NO custom folders defined.<br />';
				} /* End if ($folders_list == '') { */
			else {
				/* Defined custom folders */
				/* Building a table of already selected folders */
				$html_folders_list .= '
					The following is a list of custom folders you have previously defined.
					<div class="performancedatatool-spacer10"> </div>
					To <b>remove</b> folder(s) from the list <b>un-tick</b> the checkbox for that folder and then click the <b>Apply Settings</b> button.
					<div class="performancedatatool-spacer10"> </div>
					';
				$html_folders_list .= '<table id="folders-list-table">';
				$html_folders_list .= '<thead><tr><th class="performancedatatool-width20"></th><th>Folder Location</th><th>Type</th></tr></thead>';
				
				foreach ($folders_list as $nested_array) {
					$html_folders_list .= '<tr>';
					$html_folders_list .= '
						<td><input type="checkbox" name="folder_checkbox_'.$folder_list_counter.'" id="folder_checkbox_'.$folder_list_counter.'" class="performancedatatool-checkbox-merge-list" checked></td>
						<td><input type="text" name="folder_name_'.$folder_list_counter.'" id="folder_name_'.$folder_list_counter.'" value="'.$nested_array[0].'" class="performancedatatool-width250"/></td>
						<td>
							<select name="folder_type_'.$folder_list_counter.'" id="folder_type_'.$folder_list_counter.'" title="Folder Type">
								<option value="type1"'; if($nested_array[1] == 'type1') $html_folders_list .= ' selected'; $html_folders_list .= '>Folder containing Sub-folder(s) of Performance Data Files</option>
								<option value="type2"'; if($nested_array[1] == 'type2') $html_folders_list .= ' selected'; $html_folders_list .= '>Folder containing Performance Data Files</option>
							</select>
						</td>
						';
					$html_folders_list .= '</tr>';
					$folder_list_counter++;
					} /* End foreach ($folders_list as $nested_array) { */
				$html_folders_list .= '</table>';
				} /* End else { */
			
			/* Creating the HTML page */
			$output .= '
				<div class="sectionTitle">Custom Folders Explained</div>
				Custom folders allow you to define location(s) on your Nagios XI host that contain performance data files.
				<div class="performancedatatool-spacer10"> </div>
				The Performance Data Tool uses the <i>"/usr/local/nagios/share/perfdata"</i> folder on your Nagios XI host however there are times when you need to use a additional location(s). 
				<div class="performancedatatool-spacer10"> </div>
				One example is that you have restored some old performance data files to a temp folder and want to use these as a source to merge them into production.
				<div class="performancedatatool-spacer10"> </div>
				
				
				<!-- The following is the already defined custom folders -->
				<div class="sectionTitle">Defined Custom Folders</div>
				'.$html_folders_list.'
				<div class="performancedatatool-spacer20"> </div>
				
				
				<!-- The following is to allow the user to add a custom defined folder -->
				<div class="sectionTitle">Add A Custom Folder</div>
				To <b>add</b> a Custom Folder type the folder location as it exists on your Nagios XI host
				<div class="performancedatatool-spacer10"> </div>
				<b>Example:</b> <i>/tmp/perfdata_restored</i>
				<div class="performancedatatool-spacer10"> </div>
				<b>Tick</b> the checkbox and then click the <b>Apply Settings</b> button to add the Folder to the Defined Custom Folders list.
				<div class="performancedatatool-spacer10"> </div>
				<b>Note:</b> Folder name is CaSe SeNsAtIvE
				<div class="performancedatatool-spacer10"> </div>
				<table>
				<thead><tr><th class="performancedatatool-width20"></th><th>Folder Location</th><th>Type</th></tr></thead>
				<tr>
				<td><input type="checkbox" name="folder_checkbox_'.$folder_list_counter.'" id="folder_checkbox_'.$folder_list_counter.'" class="performancedatatool-checkbox-merge-list"></td>
				<td><input type="text" name="folder_name_'.$folder_list_counter.'" id="folder_name_'.$folder_list_counter.'" class="performancedatatool-width250"/></td>
				<td>
					<select name="folder_type_'.$folder_list_counter.'" id="folder_type_'.$folder_list_counter.'" title="Folder Type">
						<option value="type2">Folder containing Performance Data Files</option>
						<option value="type1" selected>Folder containing Sub-folder(s) of Performance Data Files</option>
					</select>
				</td>
				</tr>
				</table>
				
				
				<input type="hidden" name="folder_list_counter" id="folder_list_counter" value="'.$folder_list_counter.'">
				';
			break; /* End case COMPONENT_CONFIGMODE_GETSETTINGSHTML: */

			
		case COMPONENT_CONFIGMODE_SAVESETTINGS:
			/* Get the folder list counter */
			$folder_list_counter = grab_array_var($inargs,'folder_list_counter','');
			//print_r($folder_list_counter);
			
			/* Define the array to be used for the folders list */
			$folders_list = array();
			
			// Validation variables
			$errors = 0;
			$errmsg = array();
			
			/* Loop through the possible custom defined folders and add them to an array */
			for ($c = 0; $c <= $folder_list_counter; $c++) {
				$checkbox = 'folder_checkbox_' . $c;
				$checkbox_setting = grab_array_var($inargs,$checkbox,'');
				//print_r('checkbox ' . $c . ': ' . $checkbox_setting . '<br />');
					
				if ($checkbox_setting == 'on') {
					/* Get the values of the fields */
					$name = 'folder_name_' . $c;
					$name_value = grab_array_var($inargs,$name,'');
					$type = 'folder_type_' . $c;
					$type_value = grab_array_var($inargs,$type,'');
					
					/* Check to make sure the Folder Location field is not blank */
					if ($name_value == '') {
						$human_number = $c + 1;
						$errmsg[$errors++] = 'Folder Location CANNOT be left blank <i>(checkbox number '.$human_number.')</i>';
						} /* End if ($name_value == '') { */
					else {
						/* If the name_value ends with a forward slash, remove it */
						$name_value = rtrim($name_value, '/');
						
						/* Store this folder in the folders_list array */
						$folders_list[$c][0] = $name_value;
						$folders_list[$c][1] = $type_value;
						} /* End else { */
					} /* End if ($checkbox_setting == 'on') { */
				} /* End for ($c = 0; $c <= $folder_list_counter; $c++) { */
						
			//print_r($folders_list);
			
			/* Handle errors */
			if($errors > 0){
				$outargs[COMPONENT_ERROR_MESSAGES] = $errmsg;
				$result = 1;
				return '';
				}

			/* Save settings */
			$settings = array(
				'folders_list' => $folders_list
				);
			set_option('performancedatatool_component_options',serialize($settings));

			break; /* End case COMPONENT_CONFIGMODE_SAVESETTINGS: */

		default:
			break;

		} /* End switch($mode) { */

	return $output;
	} /* End function performancedatatool_component_config_func($mode="",$inargs,&$outargs,&$result) { */


///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function performancedatatool_component_checkversion(){

	if(!function_exists('get_product_release'))
		return false;
	//requires greater than 2009R1.2
	if(get_product_release()<114)
		return false;

	return true;
	}
	
function performancedatatool_component_addmenu($arg=null){
	global $performancedatatool_component_name;
	//retrieve the URL for this component
	$urlbase=get_component_url_base($performancedatatool_component_name);
	
	/* Check to see if the "Tools by Box293 menu exists */
	$menu_check = find_menu_item(MENU_TOOLS,"menu-tools-section-toolsbybox293","id");

	/* If the "Tools by Box293 menu does NOT exist add it */
	if ($menu_check == false) {
		/* Tools by Box293 menu */ 
		add_menu_item(MENU_TOOLS,array(
			"type" => "menusection",
			"title" => gettext("Tools by Box293"),
			"id" => "menu-tools-section-toolsbybox293",
			"order" => 10000,
			"opts" => array(
				"id" => "toolsbybox293",
				"expanded" => true,
				)
			));
		} /* End if ($menu_check == false) { */

	/* Add this to the Tools by Box293 menu */
	add_menu_item(MENU_TOOLS,array(
		"type" => "link",
		"title" => "Performance Data Tool",
		"id" => "menu-tools-section-performance-data-tool",
		"order" => 10100,
		"opts" => array(
			//this is the page the menu will actually point to.
			//all of my actual component workings will happen on this script
			"href" => $urlbase."/performance_data_tool.php",      
			)
		));

	/* If the "Tools by Box293 menu does NOT exist End it */
		if ($menu_check == false) {
			add_menu_item(MENU_TOOLS,array(
				"type" => "menusectionend",
				"id" => "menu-tools-sectionend-toolsbybox293",
				"order" => 10999,
				"title" => "",
				"opts" => ""
				));
			} /* End if ($menu_check == false) { */
				
	} /* End function performancedatatool_component_addmenu($arg=null){ */


?>
